from a10sdk.common.A10BaseClass import A10BaseClass


class DistributeInternalList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param di_cost: {"description": "Cost of route", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}
    :param di_area_num: {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}
    :param di_type: {"enum": ["lw4o6", "floating-ip", "ip-nat", "ip-nat-list", "vip", "vip-only-flagged"], "type": "string", "description": "'lw4o6': LW4O6 Prefix; 'floating-ip': Floating IP; 'ip-nat': IP NAT; 'ip-nat-list': IP NAT list; 'vip': Virtual IP (VIP); 'vip-only-flagged': Selected Virtual IP (VIP); ", "format": "enum"}
    :param di_area_ipv4: {"type": "string", "description": "OSPF area ID as a IP address format", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "distribute-internal-list"
        self.DeviceProxy = ""
        self.di_cost = ""
        self.di_area_num = ""
        self.di_type = ""
        self.di_area_ipv4 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DistributeLists(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param direction: {"enum": ["in", "out"], "type": "string", "description": "'in': Filter incoming routing updates; 'out': Filter outgoing routing updates; ", "format": "enum"}
    :param protocol: {"enum": ["bgp", "connected", "floating-ip", "lw4o6", "ip-nat", "ip-nat-list", "isis", "ospf", "rip", "static"], "type": "string", "description": "'bgp': Border Gateway Protocol (BGP); 'connected': Connected; 'floating-ip': Floating IP; 'lw4o6': LW4O6 Prefix; 'ip-nat': IP NAT; 'ip-nat-list': IP NAT list; 'isis': ISO IS-IS; 'ospf': Open Shortest Path First (OSPF); 'rip': Routing Information Protocol (RIP); 'static': Static routes; ", "format": "enum"}
    :param option: {"enum": ["only-flagged", "only-not-flagged"], "type": "string", "description": "'only-flagged': Selected Virtual IP (VIP); 'only-not-flagged': Only not flagged; ", "format": "enum"}
    :param value: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Access-list name", "format": "string"}
    :param ospf_id: {"description": "OSPF process ID", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "distribute-lists"
        self.DeviceProxy = ""
        self.direction = ""
        self.protocol = ""
        self.option = ""
        self.value = ""
        self.ospf_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RouterId(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param value: {"type": "string", "description": "OSPF router-id in IPv4 address format", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "router-id"
        self.DeviceProxy = ""
        self.value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NeighborList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param priority: {"description": "OSPF priority of non-broadcast neighbor", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}
    :param cost: {"description": "OSPF cost for point-to-multipoint neighbor (Metric)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param poll_interval: {"description": "OSPF dead-router polling interval (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param address: {"type": "string", "description": "Neighbor address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "neighbor-list"
        self.DeviceProxy = ""
        self.priority = ""
        self.cost = ""
        self.poll_interval = ""
        self.address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AbrType(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param option: {"default": "cisco", "enum": ["cisco", "ibm", "shortcut", "standard"], "type": "string", "description": "'cisco': Alternative ABR, Cisco implementation (RFC3509); 'ibm': Alternative ABR, IBM implementation (RFC3509); 'shortcut': Shortcut ABR; 'standard': Standard behavior (RFC2328); ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "abr-type"
        self.DeviceProxy = ""
        self.option = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ospf1(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ospf-1"
        self.DeviceProxy = ""
        self.abr_type = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AreaCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param area_num: {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}
    :param cost: {"description": "Cost of host", "format": "number", "default": 0, "maximum": 65535, "minimum": 0, "type": "number"}
    :param area_ipv4: {"type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "area-cfg"
        self.DeviceProxy = ""
        self.area_num = ""
        self.cost = ""
        self.area_ipv4 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class HostList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param host_address: {"type": "string", "description": "Host address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "host-list"
        self.DeviceProxy = ""
        self.host_address = ""
        self.area_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LogAdjacencyChangesCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param state: {"enum": ["detail", "disable"], "type": "string", "description": "'detail': Log changes in adjacency state; 'disable': Disable logging; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "log-adjacency-changes-cfg"
        self.DeviceProxy = ""
        self.state = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SummaryAddressList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param summary_address: {"type": "string", "description": "Configure IP address summaries (Summary prefix)", "format": "ipv4-cidr"}
    :param not_advertise: {"default": 0, "type": "number", "description": "Suppress routes that match the prefix", "format": "flag"}
    :param tag: {"description": "Set tag (32-bit tag value)", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "summary-address-list"
        self.DeviceProxy = ""
        self.summary_address = ""
        self.not_advertise = ""
        self.tag = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class EthCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ethernet: {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}
    :param eth_address: {"type": "string", "description": "Address of Interface", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "eth-cfg"
        self.DeviceProxy = ""
        self.ethernet = ""
        self.eth_address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VeCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ve_address: {"type": "string", "description": "Address of Interface", "format": "ipv4-address"}
    :param ve: {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ve-cfg"
        self.DeviceProxy = ""
        self.ve_address = ""
        self.ve = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TrunkCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param trunk_address: {"type": "string", "description": "Address of Interface", "format": "ipv4-address"}
    :param trunk: {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "trunk-cfg"
        self.DeviceProxy = ""
        self.trunk_address = ""
        self.trunk = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LoopbackCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param loopback_address: {"type": "string", "description": "Address of Interface", "format": "ipv4-address"}
    :param loopback: {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "loopback-cfg"
        self.DeviceProxy = ""
        self.loopback_address = ""
        self.loopback = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LifCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param lif: {"type": "number", "description": "Logical interface (Lif interface number)", "format": "interface"}
    :param lif_address: {"type": "string", "description": "Address of Interface", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "lif-cfg"
        self.DeviceProxy = ""
        self.lif = ""
        self.lif_address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PassiveInterface(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param eth_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet": {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}, "optional": true, "eth-address": {"type": "string", "description": "Address of Interface", "format": "ipv4-address"}}}]}
    :param ve_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ve-address": {"type": "string", "description": "Address of Interface", "format": "ipv4-address"}, "optional": true, "ve": {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}}}]}
    :param trunk_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"trunk-address": {"type": "string", "description": "Address of Interface", "format": "ipv4-address"}, "optional": true, "trunk": {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}}}]}
    :param loopback_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"loopback-address": {"type": "string", "description": "Address of Interface", "format": "ipv4-address"}, "optional": true, "loopback": {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}}}]}
    :param lif_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"lif": {"type": "number", "description": "Logical interface (Lif interface number)", "format": "interface"}, "optional": true, "lif-address": {"type": "string", "description": "Address of Interface", "format": "ipv4-address"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "passive-interface"
        self.DeviceProxy = ""
        self.eth_cfg = []
        self.ve_cfg = []
        self.trunk_cfg = []
        self.loopback_cfg = []
        self.lif_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Database(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param count: {"description": "Maximum number of LSAs", "format": "number", "default": 4294967294, "maximum": 4294967294, "minimum": 0, "type": "number"}
    :param recovery_time: {"description": "Time to recover (0 not recover)", "format": "number", "default": 0, "maximum": 65535, "minimum": 0, "type": "number"}
    :param limit: {"default": "hard", "enum": ["hard", "soft"], "type": "string", "description": "'hard': Hard limit: Instance will be shutdown if exceeded; 'soft': Soft limit: Warning will be given if exceeded; ", "format": "enum"}
    :param db_external: {"description": "Maximum number of LSAs", "format": "number", "default": 2147483647, "maximum": 2147483647, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "database"
        self.DeviceProxy = ""
        self.count = ""
        self.recovery_time = ""
        self.limit = ""
        self.db_external = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Overflow(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "overflow"
        self.DeviceProxy = ""
        self.database = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DistanceOspf(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param distance_external: {"description": "External routes (Distance for external routes)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param distance_intra_area: {"description": "Intra-area routes (Distance for intra-area routes)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param distance_inter_area: {"description": "Inter-area routes (Distance for inter-area routes)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "distance-ospf"
        self.DeviceProxy = ""
        self.distance_external = ""
        self.distance_intra_area = ""
        self.distance_inter_area = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Distance(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param distance_value: {"description": "OSPF Administrative distance", "format": "number", "default": 110, "maximum": 255, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "distance"
        self.DeviceProxy = ""
        self.distance_ospf = {}
        self.distance_value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NetworkArea(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param instance_value: {"description": "Instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}
    :param network_area_ipv4: {"type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}
    :param network_area_num: {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "network-area"
        self.DeviceProxy = ""
        self.instance_value = ""
        self.network_area_ipv4 = ""
        self.network_area_num = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NetworkList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param network_ipv4: {"type": "string", "description": "Network number", "format": "ipv4-address"}
    :param network_ipv4_cidr: {"type": "string", "description": "OSPF network prefix", "format": "ipv4-cidr"}
    :param network_ipv4_mask: {"type": "string", "description": "OSPF wild card bits", "format": "ipv4-rev-netmask"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "network-list"
        self.DeviceProxy = ""
        self.network_area = {}
        self.network_ipv4 = ""
        self.network_ipv4_cidr = ""
        self.network_ipv4_mask = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Exp(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param max_delay: {"description": "Maximum delay between receiving a change to SPF calculation in milliseconds", "format": "number", "default": 50000, "maximum": 2147483647, "minimum": 0, "type": "number"}
    :param min_delay: {"description": "Minimum delay between receiving a change to SPF calculation in milliseconds", "format": "number", "default": 500, "maximum": 2147483647, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "exp"
        self.DeviceProxy = ""
        self.max_delay = ""
        self.min_delay = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Spf(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "spf"
        self.DeviceProxy = ""
        self.exp = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Timers(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "timers"
        self.DeviceProxy = ""
        self.spf = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ospf(A10BaseClass):
    
    """Class Description::
    Open Shortest Path First (OSPF).

    Class ospf supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param distribute_internal_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"di-cost": {"description": "Cost of route", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}, "di-area-num": {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}, "optional": true, "di-type": {"enum": ["lw4o6", "floating-ip", "ip-nat", "ip-nat-list", "vip", "vip-only-flagged"], "type": "string", "description": "'lw4o6': LW4O6 Prefix; 'floating-ip': Floating IP; 'ip-nat': IP NAT; 'ip-nat-list': IP NAT list; 'vip': Virtual IP (VIP); 'vip-only-flagged': Selected Virtual IP (VIP); ", "format": "enum"}, "di-area-ipv4": {"type": "string", "description": "OSPF area ID as a IP address format", "format": "ipv4-address"}}}]}
    :param distribute_lists: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"direction": {"enum": ["in", "out"], "type": "string", "description": "'in': Filter incoming routing updates; 'out': Filter outgoing routing updates; ", "format": "enum"}, "protocol": {"enum": ["bgp", "connected", "floating-ip", "lw4o6", "ip-nat", "ip-nat-list", "isis", "ospf", "rip", "static"], "type": "string", "description": "'bgp': Border Gateway Protocol (BGP); 'connected': Connected; 'floating-ip': Floating IP; 'lw4o6': LW4O6 Prefix; 'ip-nat': IP NAT; 'ip-nat-list': IP NAT list; 'isis': ISO IS-IS; 'ospf': Open Shortest Path First (OSPF); 'rip': Routing Information Protocol (RIP); 'static': Static routes; ", "format": "enum"}, "option": {"enum": ["only-flagged", "only-not-flagged"], "type": "string", "description": "'only-flagged': Selected Virtual IP (VIP); 'only-not-flagged': Only not flagged; ", "format": "enum"}, "value": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Access-list name", "format": "string"}, "ospf-id": {"description": "OSPF process ID", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "optional": true}}]}
    :param default_metric: {"description": "Set metric of redistributed routes (Default metric)", "format": "number", "default": 20, "optional": true, "maximum": 16777214, "minimum": 1, "type": "number"}
    :param auto_cost_reference_bandwidth: {"description": "Use reference bandwidth method to assign OSPF cost (The reference bandwidth in terms of Mbits per second)", "format": "number", "default": 10000, "optional": true, "maximum": 4294967, "minimum": 1, "type": "number"}
    :param neighbor_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "OSPF priority of non-broadcast neighbor", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}, "cost": {"description": "OSPF cost for point-to-multipoint neighbor (Metric)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "optional": true, "poll-interval": {"description": "OSPF dead-router polling interval (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "address": {"type": "string", "description": "Neighbor address", "format": "ipv4-address"}}}]}
    :param host_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "host-address": {"type": "string", "description": "Host address", "format": "ipv4-address"}, "area-cfg": {"type": "object", "properties": {"area-num": {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}, "cost": {"description": "Cost of host", "format": "number", "default": 0, "maximum": 65535, "minimum": 0, "type": "number"}, "area-ipv4": {"type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}}}}}]}
    :param area_list: {"minItems": 1, "items": {"type": "area"}, "uniqueItems": true, "array": [{"required": ["area-ipv4", "area-num"], "properties": {"nssa-cfg": {"type": "object", "properties": {"no-redistribution": {"default": 0, "type": "number", "description": "No redistribution into this NSSA area", "format": "flag"}, "translator-role": {"default": "candidate", "enum": ["always", "candidate", "never"], "type": "string", "description": "'always': Translate always; 'candidate': Candidate for translator (default); 'never': Do not translate; ", "format": "enum"}, "metric": {"description": "OSPF default metric (OSPF metric)", "format": "number", "default": 1, "maximum": 16777214, "minimum": 0, "type": "number"}, "nssa": {"default": 0, "type": "number", "description": "Specify a NSSA area", "format": "flag"}, "default-information-originate": {"default": 0, "type": "number", "description": "Originate Type 7 default into NSSA area", "format": "flag"}, "no-summary": {"default": 0, "type": "number", "description": "Do not send summary LSA into NSSA", "format": "flag"}, "metric-type": {"description": "OSPF metric type (OSPF metric type for default routes)", "format": "number", "default": 2, "maximum": 2, "minimum": 1, "type": "number"}}}, "filter-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"acl-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': Filter networks sent to this area; 'out': Filter networks sent from this area; ", "format": "enum"}, "plist-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': Filter networks sent to this area; 'out': Filter networks sent from this area; ", "format": "enum"}, "acl-name": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter networks by access-list (Name of an access-list)", "format": "string"}, "plist-name": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter networks by prefix-list (Name of an IP prefix-list)", "format": "string"}, "filter-list": {"default": 0, "type": "number", "description": "Filter networks between OSPF areas", "format": "flag"}, "optional": true}}]}, "area-ipv4": {"optional": false, "type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}, "virtual-link-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dead-interval": {"description": "Dead router detection time (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "message-digest-key": {"description": "Set message digest key (Key ID)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "hello-interval": {"description": "Hello packet interval (Seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}, "transmit-delay": {"description": "LSA transmission delay (Seconds)", "format": "number", "default": 1, "maximum": 3600, "minimum": 1, "type": "number"}, "virtual-link-authentication": {"default": 0, "type": "number", "description": "Enable authentication", "format": "flag"}, "virtual-link-ip-addr": {"type": "string", "description": "ID (IP addr) associated with virtual link neighbor", "format": "ipv4-address"}, "virtual-link-auth-type": {"enum": ["message-digest", "null"], "type": "string", "description": "'message-digest': Use message-digest authentication; 'null': Use null authentication; ", "format": "enum"}, "authentication-key": {"minLength": 1, "maxLength": 8, "type": "string", "description": "Set authentication key (Authentication key (8 chars))", "format": "string-rlx"}, "retransmit-interval": {"description": "LSA retransmit interval (Seconds)", "minimum": 1, "type": "number", "maximum": 3600, "format": "number"}, "optional": true, "md5": {"minLength": 1, "maxLength": 16, "type": "string", "description": "Use MD5 algorithm (Authentication key (16 chars))", "format": "string-rlx"}}}]}, "stub-cfg": {"type": "object", "properties": {"stub": {"default": 0, "type": "number", "description": "Configure OSPF area as stub", "format": "flag"}, "no-summary": {"default": 0, "type": "number", "description": "Do not inject inter-area routes into area", "format": "flag"}}}, "shortcut": {"description": "'default': Set default shortcutting behavior; 'disable': Disable shortcutting through the area; 'enable': Enable shortcutting through the area; ", "format": "enum", "default": "default", "type": "string", "enum": ["default", "disable", "enable"], "optional": true}, "auth-cfg": {"type": "object", "properties": {"authentication": {"default": 0, "type": "number", "description": "Enable authentication", "format": "flag"}, "message-digest": {"default": 0, "type": "number", "description": "Use message-digest authentication", "format": "flag"}}}, "range-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"area-range-prefix": {"type": "string", "description": "Area range for IPv4 prefix", "format": "ipv4-cidr"}, "optional": true, "option": {"default": "advertise", "enum": ["advertise", "not-advertise"], "type": "string", "description": "'advertise': Advertise this range (default); 'not-advertise': DoNotAdvertise this range; ", "format": "enum"}}}]}, "default-cost": {"description": "Set the summary-default cost of a NSSA or stub area (Stub's advertised default summary cost)", "format": "number", "default": 1, "optional": true, "maximum": 16777215, "minimum": 0, "type": "number"}, "area-num": {"description": "OSPF area ID as a decimal value", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 0, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/router/ospf/{process-id}/area/{area-ipv4}+{area-num}"}
    :param maximum_area: {"description": "Maximum number of OSPF area (OSPF area limit)", "format": "number", "type": "number", "maximum": 4294967294, "minimum": 1, "optional": true}
    :param summary_address_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"summary-address": {"type": "string", "description": "Configure IP address summaries (Summary prefix)", "format": "ipv4-cidr"}, "not-advertise": {"default": 0, "type": "number", "description": "Suppress routes that match the prefix", "format": "flag"}, "tag": {"description": "Set tag (32-bit tag value)", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}, "optional": true}}]}
    :param rfc1583_compatible: {"default": 0, "optional": true, "type": "number", "description": "Compatible with RFC 1583", "format": "flag"}
    :param max_concurrent_dd: {"description": "Maximum number allowed to process DD concurrently (Number of DD process)", "format": "number", "default": 5, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param process_id: {"description": "OSPF process ID", "format": "number", "default": 0, "optional": false, "maximum": 65535, "minimum": 0, "type": "number"}
    :param bfd_all_interfaces: {"default": 0, "optional": true, "type": "number", "description": "Enable BFD on all interfaces", "format": "flag"}
    :param network_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"network-area": {"type": "object", "properties": {"instance-value": {"description": "Instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}, "network-area-ipv4": {"type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}, "network-area-num": {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}}}, "network-ipv4": {"type": "string", "description": "Network number", "format": "ipv4-address"}, "network-ipv4-cidr": {"type": "string", "description": "OSPF network prefix", "format": "ipv4-cidr"}, "network-ipv4-mask": {"type": "string", "description": "OSPF wild card bits", "format": "ipv4-rev-netmask"}, "optional": true}}]}
    :param ha_standby_extra_cost: {"description": "Extra ospf cost when there is any standby HA group (The extra cost value)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/ospf/{process_id}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "process_id"]

        self.b_key = "ospf"
        self.a10_url="/axapi/v3/router/ospf/{process_id}"
        self.DeviceProxy = ""
        self.distribute_internal_list = []
        self.distribute_lists = []
        self.default_metric = ""
        self.auto_cost_reference_bandwidth = ""
        self.router_id = {}
        self.neighbor_list = []
        self.ospf_1 = {}
        self.host_list = []
        self.log_adjacency_changes_cfg = {}
        self.area_list = []
        self.maximum_area = ""
        self.summary_address_list = []
        self.rfc1583_compatible = ""
        self.max_concurrent_dd = ""
        self.process_id = ""
        self.passive_interface = {}
        self.default_information = {}
        self.overflow = {}
        self.bfd_all_interfaces = ""
        self.distance = {}
        self.redistribute = {}
        self.network_list = []
        self.timers = {}
        self.ha_standby_extra_cost = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class EthernetCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ethernet: {"type": "number", "description": "Ethernet (Ethernet interface number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ethernet-cfg"
        self.DeviceProxy = ""
        self.ethernet = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VeCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ve: {"description": "VE interface (VE interface number)", "minimum": 2, "type": "number", "maximum": 4094, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ve-cfg"
        self.DeviceProxy = ""
        self.ve = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TrunkCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param trunk: {"description": "Trunk interface (Trunk interface number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "trunk-cfg"
        self.DeviceProxy = ""
        self.trunk = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Device(A10BaseClass):
    
    """Class Description::
    VCS Device.

    Class device supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param management: {"default": 0, "optional": true, "type": "number", "description": "Management interface", "format": "flag"}
    :param ethernet_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet": {"type": "number", "description": "Ethernet (Ethernet interface number)", "format": "interface"}, "optional": true}}]}
    :param priority: {"description": "Device priority", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}
    :param enable: {"default": 0, "optional": true, "type": "number", "description": "Enable", "format": "flag"}
    :param ve_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "ve": {"description": "VE interface (VE interface number)", "minimum": 2, "type": "number", "maximum": 4094, "format": "number"}}}]}
    :param device: {"description": "Device ID", "format": "number", "type": "number", "maximum": 8, "minimum": 1, "optional": false}
    :param affinity_vrrp_a_vrid: {"description": "vrid-group", "format": "number", "type": "number", "maximum": 31, "minimum": 0, "optional": true}
    :param unicast_port: {"description": "Port used in unicast communication (Port number)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1024, "optional": true}
    :param trunk_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "trunk": {"description": "Trunk interface (Trunk interface number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vcs/device/{device}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "device"]

        self.b_key = "device"
        self.a10_url="/axapi/v3/vcs/device/{device}"
        self.DeviceProxy = ""
        self.management = ""
        self.ethernet_cfg = []
        self.priority = ""
        self.enable = ""
        self.ve_cfg = []
        self.device = ""
        self.affinity_vrrp_a_vrid = ""
        self.unicast_port = ""
        self.trunk_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class GeoLocationMatch(A10BaseClass):
    
    """Class Description::
    Specify match order of geographic.

    Class geo-location-match supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param geo_type_overlap: {"optional": true, "enum": ["global", "policy"], "type": "string", "description": "'global': Global Geo-location; 'policy': Policy Geo-location; ", "format": "enum"}
    :param overlap: {"default": 0, "optional": true, "type": "number", "description": "Enable overlap mode to do longest match", "format": "flag"}
    :param match_first: {"description": "'global': Global Geo-location; 'policy': Policy Geo-location; ", "format": "enum", "default": "global", "type": "string", "enum": ["global", "policy"], "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/policy/{name}/geo-location-match`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "geo-location-match"
        self.a10_url="/axapi/v3/gslb/policy/{name}/geo-location-match"
        self.DeviceProxy = ""
        self.geo_type_overlap = ""
        self.overlap = ""
        self.match_first = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Invalid_cred: {"description": "Invalid Credential", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param Bad_req: {"description": "Bad Request", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param Other_error: {"description": "Other Error", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param Request: {"description": "Request", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param Invalid_srv_rsp: {"description": "Invalid Server Response", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param Post_fail: {"description": "POST Failed", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param Error: {"description": "Internal Server Error", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param Not_fnd: {"description": "Not Found", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.Invalid_cred = ""
        self.Bad_req = ""
        self.Other_error = ""
        self.Request = ""
        self.Invalid_srv_rsp = ""
        self.Post_fail = ""
        self.Error = ""
        self.Not_fnd = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Instance(A10BaseClass):
    
    """Class Description::
    Statistics for the object instance.

    Class instance supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "Specify form-based authentication relay name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param request_uri_list: {"minItems": 1, "items": {"type": "request-uri"}, "uniqueItems": true, "array": [{"required": ["match-type", "uri"], "properties": {}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/relay/form-based/instance/{name}/request-uri/{match-type}+{uri}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/relay/form-based/instance/{name}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "instance"
        self.a10_url="/axapi/v3/aam/authentication/relay/form-based/instance/{name}/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.name = ""
        self.request_uri_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class FileList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param template: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param file: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param syntax: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "file-list"
        self.DeviceProxy = ""
        self.template = ""
        self.A10WW_file = ""
        self.syntax = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param file_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "template": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "file": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "syntax": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.file_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class XmlSchema(A10BaseClass):
    
    """Class Description::
    Operational Status for the object xml-schema.

    Class xml-schema supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/file/xml-schema/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "xml-schema"
        self.a10_url="/axapi/v3/file/xml-schema/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param no_rev_route: {"description": "No Reverse Route for Session", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param tcp_rst_sent: {"description": "TCP RST Sent", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param icmp_reply_no_session_drop: {"description": "ICMP Reply No Session Drop", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param ipv6_src_invalid_unicast: {"description": "IPv6 Source Not Valid Unicast", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param icmp_filtered_sent: {"description": "ICMP Administratively Filtered Sent", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param ipv6_dst_invalid_unicast: {"description": "IPv6 Destination Not Valid Unicast", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param ipip_icmp_reply_sent: {"description": "IPIP ICMP Echo Reply Sent", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param ip_dst_invalid_unicast: {"description": "IPv4 Destination Not Valid Unicast", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param no_fwd_route: {"description": "No Forward Route for Session", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param ip_src_invalid_unicast: {"description": "IPv4 Source Not Valid Unicast", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param icmp_host_unreachable_sent: {"description": "ICMP Host Unreachable Sent", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param out_of_session_memory: {"description": "Out of Session Memory", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param ipip_truncated: {"description": "IPIP Truncated Packet", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.no_rev_route = ""
        self.tcp_rst_sent = ""
        self.icmp_reply_no_session_drop = ""
        self.ipv6_src_invalid_unicast = ""
        self.icmp_filtered_sent = ""
        self.ipv6_dst_invalid_unicast = ""
        self.ipip_icmp_reply_sent = ""
        self.ip_dst_invalid_unicast = ""
        self.no_fwd_route = ""
        self.ip_src_invalid_unicast = ""
        self.icmp_host_unreachable_sent = ""
        self.out_of_session_memory = ""
        self.ipip_truncated = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class L4(A10BaseClass):
    
    """Class Description::
    Statistics for the object l4.

    Class l4 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/l4/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "l4"
        self.a10_url="/axapi/v3/cgnv6/l4/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param passthrough: {"optional": true, "size": "8", "type": "number", "oid": "1", "format": "counter"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.passthrough = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Vpn(A10BaseClass):
    
    """Class Description::
    Statistics for the object vpn.

    Class vpn supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ike_gateway_list: {"minItems": 1, "items": {"type": "ike-gateway"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {}}], "type": "array", "$ref": "/axapi/v3/vpn/ike-gateway/{name}"}
    :param revocation_list: {"minItems": 1, "items": {"type": "revocation"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {}}], "type": "array", "$ref": "/axapi/v3/vpn/ike-gateway/{name}/ipsec/{name}/revocation/{name}"}
    :param ipsec_list: {"minItems": 1, "items": {"type": "ipsec"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"stats": {"type": "object", "properties": {"packets-err-icv-check": {"optional": true, "size": "4", "type": "number", "oid": "9", "format": "counter"}, "packets-err-lifetime-lifebytes": {"optional": true, "size": "8", "type": "number", "oid": "11", "format": "counter"}, "packets-err-badspi": {"optional": true, "size": "4", "type": "number", "oid": "10", "format": "counter"}, "cavium-err-enc": {"optional": true, "size": "4", "type": "number", "oid": "18", "format": "counter"}, "bytes-encrypted": {"optional": true, "size": "4", "type": "number", "oid": "12", "format": "counter"}, "anti-replay-num": {"optional": true, "size": "8", "type": "number", "oid": "3", "format": "counter"}, "prefrag-error": {"optional": true, "size": "4", "type": "number", "oid": "15", "format": "counter"}, "packets-err-encryption": {"optional": true, "size": "4", "type": "number", "oid": "6", "format": "counter"}, "rekey-num": {"optional": true, "size": "8", "type": "number", "oid": "4", "format": "counter"}, "frags-created": {"optional": true, "size": "4", "type": "number", "oid": "16", "format": "counter"}, "packets-err-inactive": {"optional": true, "size": "4", "type": "number", "oid": "5", "format": "counter"}, "prefrag-success": {"optional": true, "size": "4", "type": "number", "oid": "14", "format": "counter"}, "packets-err-pad-check": {"optional": true, "size": "4", "type": "number", "oid": "7", "format": "counter"}, "packets-err-pkt-sanity": {"optional": true, "size": "4", "type": "number", "oid": "8", "format": "counter"}, "packets-decrypted": {"optional": true, "size": "8", "type": "number", "oid": "2", "format": "counter"}, "frags-reassembled": {"optional": true, "size": "4", "type": "number", "oid": "17", "format": "counter"}, "packets-encrypted": {"optional": true, "size": "8", "type": "number", "oid": "1", "format": "counter"}, "cavium-err-dec": {"optional": true, "size": "4", "type": "number", "oid": "19", "format": "counter"}, "bytes-decrypted": {"optional": true, "size": "4", "type": "number", "oid": "13", "format": "counter"}}}, "name": {"description": "IPsec name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 31, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/vpn/ike-gateway/{name}/ipsec/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vpn/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "vpn"
        self.a10_url="/axapi/v3/vpn/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.ike_gateway_list = []
        self.revocation_list = []
        self.ipsec_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class HealthCheckGateway(A10BaseClass):
    
    """Class Description::
    Configure LW-4over6 health-check gateway.

    Class health-check-gateway supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ipv4_addr: {"optional": false, "type": "string", "description": "LW-4over6 IPv4 Gateway", "format": "ipv4-address"}
    :param ipv6_addr: {"optional": false, "type": "string", "description": "LW-4over6 IPv6 Gateway", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lw-4o6/health-check-gateway/{ipv4_addr}+{ipv6_addr}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ipv4_addr","ipv6_addr"]

        self.b_key = "health-check-gateway"
        self.a10_url="/axapi/v3/cgnv6/lw-4o6/health-check-gateway/{ipv4_addr}+{ipv6_addr}"
        self.DeviceProxy = ""
        self.ipv4_addr = ""
        self.ipv6_addr = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class RemoteCaCert(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param remote_cert_name: {"minLength": 1, "maxLength": 127, "type": "string", "description": "CA Certificate DN", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "remote-ca-cert"
        self.DeviceProxy = ""
        self.remote_cert_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LocalAddress(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param local_ip: {"type": "string", "description": "Ipv4 address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "local-address"
        self.DeviceProxy = ""
        self.local_ip = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Vrid(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param default: {"default": 0, "not": "vrid-num", "type": "number", "description": "Default VRRP-A vrid", "format": "flag"}
    :param vrid_num: {"description": "Specify ha VRRP-A vrid", "format": "number", "maximum": 31, "minimum": 1, "not": "default", "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "vrid"
        self.DeviceProxy = ""
        self.default = ""
        self.vrid_num = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LocalCert(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param local_cert_name: {"minLength": 1, "maxLength": 64, "type": "string", "description": "Certificate File Name", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "local-cert"
        self.DeviceProxy = ""
        self.local_cert_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Dpd(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param interval: {"description": "Interval time in seconds", "minimum": 0, "type": "number", "maximum": 10, "format": "number"}
    :param retry: {"description": "Retry times", "minimum": 1, "type": "number", "maximum": 10, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dpd"
        self.DeviceProxy = ""
        self.interval = ""
        self.retry = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Key(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param key_passphrase: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Private Key Pass Phrase", "format": "string"}
    :param key_name: {"minLength": 1, "maxLength": 64, "type": "string", "description": "Private Key File Name", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "key"
        self.DeviceProxy = ""
        self.key_passphrase = ""
        self.key_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RemoteAddress(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param remote_ip: {"not": "dns", "type": "string", "description": "Ipv4 address", "format": "ipv4-address"}
    :param dns: {"description": "Remote IP based on Domain name", "format": "string", "minLength": 1, "maxLength": 128, "not": "remote-ip", "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "remote-address"
        self.DeviceProxy = ""
        self.remote_ip = ""
        self.dns = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class EncCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param priority: {"description": "Prioritizes (1-10) security protocol, least value has highest priority", "format": "number", "default": 5, "maximum": 10, "minimum": 1, "type": "number"}
    :param encryption: {"enum": ["des", "3des", "aes-128", "aes-192", "aes-256", "null"], "type": "string", "description": "'des': Data Encryption Standard algorithm; '3des': Triple Data Encryption Standard algorithm; 'aes-128': Advanced Encryption Standard algorithm (key size: 128 bits); 'aes-192': Advanced Encryption Standard algorithm (key size: 192 bits); 'aes-256': Advanced Encryption Standard algorithm (key size: 256 bits); 'null': No encryption algorithm; ", "format": "enum"}
    :param hash: {"enum": ["md5", "sha1", "sha256", "null"], "type": "string", "description": "'md5': MD5 Dessage-Digest Algorithm; 'sha1': Secure Hash Algorithm 1; 'sha256': Secure Hash Algorithm 256; 'null': No hash algorithm; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "enc-cfg"
        self.DeviceProxy = ""
        self.priority = ""
        self.encryption = ""
        self.A10WW_hash = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AuthMethod(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param preshare_key: {"description": "Authenticate the remote gateway using a pre-shared key", "format": "string", "minLength": 1, "maxLength": 127, "not": "rsa-signature", "type": "string"}
    :param rsa_signature: {"default": 0, "not": "preshare-key", "type": "number", "description": "Authenticate the remote gateway using an RSA certificate", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "auth-method"
        self.DeviceProxy = ""
        self.preshare_key = ""
        self.rsa_signature = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IkeGateway(A10BaseClass):
    
    """Class Description::
    IKE-gateway settings.

    Class ike-gateway supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "IKE-gateway name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param dh_group: {"optional": true, "enum": ["1", "2", "5", "14", "15", "16", "18"], "type": "string", "description": "'1': Diffie-Hellman group 1 (Default); '2': Diffie-Hellman group 2; '5': Diffie-Hellman group 5; '14': Diffie-Hellman group 14; '15': Diffie-Hellman group 15; '16': Diffie-Hellman group 16; '18': Diffie-Hellman group 18; ", "format": "enum"}
    :param nat_traversal: {"default": 0, "optional": true, "type": "number", "format": "flag"}
    :param ike_version: {"optional": true, "enum": ["v1", "v2"], "type": "string", "description": "'v1': IKEv1 key exchange; 'v2': IKEv2 key exchange; ", "format": "enum"}
    :param mode: {"optional": true, "enum": ["main", "aggressive"], "type": "string", "description": "'main': Negotiate Main mode (Default); 'aggressive': Negotiate Aggressive mode; ", "format": "enum"}
    :param lifetime: {"description": "IKE SA age in seconds", "format": "number", "default": 86400, "optional": true, "maximum": 86400, "minimum": 300, "type": "number"}
    :param remote_id: {"description": "Remote Gateway Identity", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param local_id: {"description": "Local Gateway Identity", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param enc_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Prioritizes (1-10) security protocol, least value has highest priority", "format": "number", "default": 5, "maximum": 10, "minimum": 1, "type": "number"}, "encryption": {"enum": ["des", "3des", "aes-128", "aes-192", "aes-256", "null"], "type": "string", "description": "'des': Data Encryption Standard algorithm; '3des': Triple Data Encryption Standard algorithm; 'aes-128': Advanced Encryption Standard algorithm (key size: 128 bits); 'aes-192': Advanced Encryption Standard algorithm (key size: 192 bits); 'aes-256': Advanced Encryption Standard algorithm (key size: 256 bits); 'null': No encryption algorithm; ", "format": "enum"}, "hash": {"enum": ["md5", "sha1", "sha256", "null"], "type": "string", "description": "'md5': MD5 Dessage-Digest Algorithm; 'sha1': Secure Hash Algorithm 1; 'sha256': Secure Hash Algorithm 256; 'null': No hash algorithm; ", "format": "enum"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vpn/ike-gateway/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "ike-gateway"
        self.a10_url="/axapi/v3/vpn/ike-gateway/{name}"
        self.DeviceProxy = ""
        self.remote_ca_cert = {}
        self.local_address = {}
        self.name = ""
        self.dh_group = ""
        self.nat_traversal = ""
        self.vrid = {}
        self.ike_version = ""
        self.local_cert = {}
        self.dpd = {}
        self.mode = ""
        self.key = {}
        self.lifetime = ""
        self.remote_address = {}
        self.remote_id = ""
        self.local_id = ""
        self.enc_cfg = []
        self.auth_method = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param out_echo_req: {"description": "Out Echo requests", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "2"}
    :param out_param_prob: {"description": "Out Parameter Problem", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "2"}
    :param out_pkt_too_big: {"description": "Out Packet too big", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "2"}
    :param out_na: {"description": "Out neighbor advertisement", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "2"}
    :param out_rs: {"description": "Out Router solicitation", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "2"}
    :param err_ns: {"description": "Error Neighbor solicitation", "format": "counter", "type": "number", "oid": "33", "optional": true, "size": "2"}
    :param in_redirect: {"description": "In Redirects", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "2"}
    :param in_echoes: {"description": "In Echo requests", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "2"}
    :param out_ns: {"description": "Out neighbor solicitation", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "2"}
    :param err_na: {"description": "Error Neighbor advertisement", "format": "counter", "type": "number", "oid": "34", "optional": true, "size": "2"}
    :param out_ra: {"description": "Out Router advertisement", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "2"}
    :param out_mem_reductions: {"description": "Out Group member reduction", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "2"}
    :param out_dst_un_reach: {"description": "Out Destination Unreachable", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "2"}
    :param in_msgs: {"description": "In messages", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "2"}
    :param in_param_prob: {"description": "In Parameter Problem", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "2"}
    :param in_pkt_too_big: {"description": "In Packet too big", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "2"}
    :param err_ra: {"description": "Error Router advertisement", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "2"}
    :param in_grp_mem_resp: {"description": "In Group member reply", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "2"}
    :param err_echoes: {"description": "Error Echo requests", "format": "counter", "type": "number", "oid": "36", "optional": true, "size": "2"}
    :param in_errors: {"description": "In Errors", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "2"}
    :param out_echo_replies: {"description": "Out Echo replies", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "2"}
    :param in_na: {"description": "In neighbor advertisement", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "2"}
    :param in_ra: {"description": "In Router advertisement", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "2"}
    :param err_rs: {"description": "Error Router solicitation", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "2"}
    :param err_redirects: {"description": "Error Redirects", "format": "counter", "type": "number", "oid": "35", "optional": true, "size": "2"}
    :param err_echo_replies: {"description": "Error Echo replies", "format": "counter", "type": "number", "oid": "37", "optional": true, "size": "2"}
    :param in_ns: {"description": "In neighbor solicitation", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "2"}
    :param out_msg: {"description": "Out Messages", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "2"}
    :param out_mem_resp: {"description": "Out Group member reply", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "2"}
    :param out_time_exceeds: {"description": "Out TTL Exceeds", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "2"}
    :param in_exho_reply: {"description": "In Echo replies", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "2"}
    :param in_router_sol: {"description": "In Router solicitation", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "2"}
    :param in_grp_mem_query: {"description": "In Group member query", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "2"}
    :param out_redirects: {"description": "Out Redirects", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "2"}
    :param in_time_exceeds: {"description": "In TTL Exceeds", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "2"}
    :param in_grp_mem_reduction: {"description": "In Group member reduction", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "2"}
    :param in_dest_un_reach: {"description": "In Destunation Unreachable", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "2"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.out_echo_req = ""
        self.out_param_prob = ""
        self.out_pkt_too_big = ""
        self.out_na = ""
        self.out_rs = ""
        self.err_ns = ""
        self.in_redirect = ""
        self.in_echoes = ""
        self.out_ns = ""
        self.err_na = ""
        self.out_ra = ""
        self.out_mem_reductions = ""
        self.out_dst_un_reach = ""
        self.in_msgs = ""
        self.in_param_prob = ""
        self.in_pkt_too_big = ""
        self.err_ra = ""
        self.in_grp_mem_resp = ""
        self.err_echoes = ""
        self.in_errors = ""
        self.out_echo_replies = ""
        self.in_na = ""
        self.in_ra = ""
        self.err_rs = ""
        self.err_redirects = ""
        self.err_echo_replies = ""
        self.in_ns = ""
        self.out_msg = ""
        self.out_mem_resp = ""
        self.out_time_exceeds = ""
        self.in_exho_reply = ""
        self.in_router_sol = ""
        self.in_grp_mem_query = ""
        self.out_redirects = ""
        self.in_time_exceeds = ""
        self.in_grp_mem_reduction = ""
        self.in_dest_un_reach = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Icmp6(A10BaseClass):
    
    """Class Description::
    Statistics for the object icmp6.

    Class icmp6 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/system/icmp6/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "icmp6"
        self.a10_url="/axapi/v3/system/icmp6/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PostModifyParent(A10BaseClass):
    
    """Class Description::
    Unit test of post modify ineligible.

    Class post-modify-parent supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param k1: {"minLength": 1, "maxLength": 32, "type": "string", "optional": false, "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cm-ut/post-modify-parent/{k1}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "k1"]

        self.b_key = "post-modify-parent"
        self.a10_url="/axapi/v3/cm-ut/post-modify-parent/{k1}"
        self.DeviceProxy = ""
        self.post_modify_child = {}
        self.k1 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PortList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param port_start: {"type": "number", "description": "Single Port or Port Range Start", "format": "number"}
    :param port_end: {"type": "number", "description": "Port Range End", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "port-list"
        self.DeviceProxy = ""
        self.port_start = ""
        self.port_end = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NatAddress(A10BaseClass):
    
    """    :param ipv4_nat_addr: {"optional": false, "type": "string", "description": "NAT IPv4 Address", "format": "ipv4-address"}
    :param port_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "port-start": {"type": "number", "description": "Single Port or Port Range Start", "format": "number"}, "port-end": {"type": "number", "description": "Port Range End", "format": "number"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    NAT IPv4 address.

    Class nat-address supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lw-4o6/binding-table/{name}/tunnel-address/{ipv6_tunnel_addr}/nat-address/{ipv4_nat_addr}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ipv4_nat_addr"]

        self.b_key = "nat-address"
        self.a10_url="/axapi/v3/cgnv6/lw-4o6/binding-table/{name}/tunnel-address/{ipv6_tunnel_addr}/nat-address/{ipv4_nat_addr}"
        self.DeviceProxy = ""
        self.ipv4_nat_addr = ""
        self.port_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Member(A10BaseClass):
    
    """Class Description::
    Add a CGNv6 one-to-one pool to this pool-group.

    Class member supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param pool_name: {"description": "Specify CGNv6 one-to-one pool name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/one-to-one/pool-group/{pool_group_name}/member/{pool_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "pool_name"]

        self.b_key = "member"
        self.a10_url="/axapi/v3/cgnv6/one-to-one/pool-group/{pool_group_name}/member/{pool_name}"
        self.DeviceProxy = ""
        self.pool_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param miss_resp: {"description": "Missed resp", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param ntermi_err: {"description": "Total terminated by err", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param current_open: {"description": "Open persist", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param current_active: {"description": "Active persist", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param pause_conn: {"description": "Pause request", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param delay_unbind: {"description": "Delayed unbind", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param long_resp: {"description": "Long resp", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param ntermi: {"description": "Total terminated", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param pause_conn_fail: {"description": "Pause request fail", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param nunbind: {"description": "Total unbind", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param unbound_data_rcv: {"description": "Unbound data rcvd", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param resume_conn: {"description": "Resume request", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param nbind: {"description": "Total bind", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param not_remove_from_rport: {"description": "Not remove from list", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param nestab: {"description": "Total established", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.miss_resp = ""
        self.ntermi_err = ""
        self.current_open = ""
        self.current_active = ""
        self.pause_conn = ""
        self.delay_unbind = ""
        self.long_resp = ""
        self.ntermi = ""
        self.pause_conn_fail = ""
        self.nunbind = ""
        self.unbound_data_rcv = ""
        self.resume_conn = ""
        self.nbind = ""
        self.not_remove_from_rport = ""
        self.nestab = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ConnectionReuse(A10BaseClass):
    
    """Class Description::
    Statistics for the object connection-reuse.

    Class connection-reuse supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/connection-reuse/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "connection-reuse"
        self.a10_url="/axapi/v3/slb/connection-reuse/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class EnableCore(A10BaseClass):
    
    """Class Description::
    Enable system coredump switch.

    Class enable-core supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param core_level: {"description": "'a10': Enable A10 core dump, by default; 'system': Enable system coredump; ", "format": "enum", "default": "a10", "optional": true, "enum": ["a10", "system"], "not": "full", "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/enable-core`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "enable-core"
        self.a10_url="/axapi/v3/enable-core"
        self.DeviceProxy = ""
        self.core_level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param weight: {"type": "number", "format": "number"}
    :param priority: {"type": "number", "format": "number"}
    :param state: {"enum": ["Active", "Standby"], "type": "string", "format": "enum"}
    :param became_active: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param force_standby: {"type": "number", "format": "number"}
    :param unit: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.weight = ""
        self.priority = ""
        self.state = ""
        self.became_active = ""
        self.force_standby = ""
        self.unit = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Gateway(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "gateway"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TrackingOptions(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "tracking-options"
        self.DeviceProxy = ""
        self.oper = {}
        self.gateway = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class BladeParameters(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "blade-parameters"
        self.DeviceProxy = ""
        self.oper = {}
        self.tracking_options = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Vrid(A10BaseClass):
    
    """Class Description::
    Operational Status for the object vrid.

    Class vrid supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param vrid_val: {"description": "Specify ha VRRP-A vrid", "format": "number", "default": 0, "optional": false, "oid": "1001", "maximum": 31, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vrrp-a/vrid/{vrid_val}/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "vrid"
        self.a10_url="/axapi/v3/vrrp-a/vrid/{vrid_val}/oper"
        self.DeviceProxy = ""
        self.oper = {}
        self.blade_parameters = {}
        self.vrid_val = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param num_tx_pkts: {"description": "Transmitted packtes", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param rate_byte_rcvd: {"description": "Byte received rate bits/sec", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param num_total_tx_bytes: {"description": "Transmitte bytes", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param rate_pkt_rcvd: {"description": "Packet received rate packets/sec", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param num_multicast_pkts: {"description": "Received multicasts", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param num_unicast_pkts: {"description": "Received unicasts", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param num_broadcast_tx_pkts: {"description": "Transmitted broadcasts", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param num_broadcast_pkts: {"description": "Received braodcasts", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param num_multicast_tx_pkts: {"description": "Transmitted multicasts", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param rate_byte_sent: {"description": "Byte sent rate bits/sec", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param num_unicast_tx_pkts: {"description": "Trasnmitted unicasts", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param num_total_bytes: {"description": "Input bytes", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param load_interval: {"description": "Load Interval", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param num_pkts: {"description": "Input packets", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param rate_pkt_sent: {"description": "Packet sent rate packets/sec", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.num_tx_pkts = ""
        self.rate_byte_rcvd = ""
        self.num_total_tx_bytes = ""
        self.rate_pkt_rcvd = ""
        self.num_multicast_pkts = ""
        self.num_unicast_pkts = ""
        self.num_broadcast_tx_pkts = ""
        self.num_broadcast_pkts = ""
        self.num_multicast_tx_pkts = ""
        self.rate_byte_sent = ""
        self.num_unicast_tx_pkts = ""
        self.num_total_bytes = ""
        self.load_interval = ""
        self.num_pkts = ""
        self.rate_pkt_sent = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ve(A10BaseClass):
    
    """Class Description::
    Statistics for the object ve.

    Class ve supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ifnum: {"optional": false, "oid": "1001", "type": "number", "description": "Virtual ethernet interface number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/ve/{ifnum}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ifnum"]

        self.b_key = "ve"
        self.a10_url="/axapi/v3/interface/ve/{ifnum}/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.bfd = {}
        self.ip = {}
        self.ddos = {}
        self.ifnum = ""
        self.lw_4o6 = {}
        self.ipv6 = {}
        self.isis = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Server(A10BaseClass):
    
    """Class Description::
    CGNV6 logging Server.

    Class server supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param health_check_disable: {"description": "Disable configured health check configuration", "format": "flag", "default": 0, "optional": true, "not": "health-check", "type": "number"}
    :param port_list: {"minItems": 1, "items": {"type": "port"}, "uniqueItems": true, "array": [{"required": ["port-number", "protocol"], "properties": {"action": {"description": "'enable': enable; 'disable': disable; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}, "health-check-disable": {"description": "Disable health check", "format": "flag", "default": 0, "optional": true, "not": "health-check", "type": "number"}, "protocol": {"optional": false, "enum": ["tcp", "udp"], "type": "string", "description": "'tcp': TCP Port; 'udp': UDP Port; ", "format": "enum"}, "health-check": {"description": "Health Check (Monitor Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "not": "health-check-disable", "type": "string", "$ref": "/axapi/v3/health/monitor"}, "port-number": {"description": "Port Number", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/server/{name}/port/{port-number}+{protocol}"}
    :param name: {"description": "Server Name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}
    :param fqdn_name: {"description": "Server hostname", "format": "string", "minLength": 1, "modify-not-allowed": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param host: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "IP Address", "format": "ipv4-address"}
    :param action: {"description": "'enable': Enable this Real Server; 'disable': Disable this Real Server; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}
    :param server_ipv6_addr: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "IPV6 address", "format": "ipv6-address"}
    :param health_check: {"description": "Health Check Monitor (Health monitor name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "not": "health-check-disable", "type": "string", "$ref": "/axapi/v3/health/monitor"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/server/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "server"
        self.a10_url="/axapi/v3/cgnv6/server/{name}"
        self.DeviceProxy = ""
        self.health_check_disable = ""
        self.port_list = []
        self.name = ""
        self.fqdn_name = ""
        self.host = ""
        self.action = ""
        self.server_ipv6_addr = ""
        self.health_check = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Rba(A10BaseClass):
    
    """Class Description::
    Role Based Access configuration.

    Class rba supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param action: {"description": "'enable': Enable RBA; 'disable': Disable RBA; ", "format": "enum", "default": "disable", "type": "string", "enum": ["enable", "disable"], "optional": true}
    :param group_list: {"minItems": 1, "items": {"type": "group"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"partition-list": {"minItems": 1, "items": {"type": "partition"}, "uniqueItems": true, "array": [{"required": ["partition-name"], "properties": {"partition-name": {"description": "partition name", "format": "string", "minLength": 1, "optional": false, "maxLength": 14, "type": "string"}, "role-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "role": {"description": "Role in a given partition", "format": "string", "minLength": 1, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/rba/role"}}}]}, "rule-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"operation": {"enum": ["no-access", "read", "write"], "type": "string", "description": "'no-access': no-access; 'read': read; 'write': write; ", "format": "enum"}, "object": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Lineage of object class for permitted operation", "format": "string"}, "optional": true}}]}}}], "type": "array", "$ref": "/axapi/v3/rba/group/{name}/partition/{partition-name}"}, "user-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "user": {"minLength": 1, "maxLength": 32, "type": "string", "description": "Users in the group", "format": "string"}}}]}, "name": {"description": "Name of a RBA group", "format": "string", "minLength": 1, "optional": false, "maxLength": 32, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/rba/group/{name}"}
    :param user_list: {"minItems": 1, "items": {"type": "user"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"partition-list": {"minItems": 1, "items": {"type": "partition"}, "uniqueItems": true, "array": [{"required": ["partition-name"], "properties": {"partition-name": {"description": "partition name", "format": "string", "minLength": 1, "optional": false, "maxLength": 14, "type": "string"}, "role-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "role": {"description": "Role in a given partition", "format": "string", "minLength": 1, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/rba/role"}}}]}, "rule-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"operation": {"enum": ["no-access", "read", "write"], "type": "string", "description": "'no-access': no-access; 'read': read; 'write': write; ", "format": "enum"}, "object": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Lineage of object class for permitted operation", "format": "string"}, "optional": true}}]}}}], "type": "array", "$ref": "/axapi/v3/rba/user/{name}/partition/{partition-name}"}, "name": {"description": "Name of a user account", "format": "string", "minLength": 1, "optional": false, "maxLength": 32, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/rba/user/{name}"}
    :param role_list: {"minItems": 1, "items": {"type": "role"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"name": {"description": "Name for the RBA role", "format": "string", "minLength": 1, "optional": false, "maxLength": 32, "type": "string"}, "rule-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"operation": {"enum": ["no-access", "read", "write"], "type": "string", "description": "'no-access': no-access; 'read': read; 'write': write; ", "format": "enum"}, "object": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Lineage of object class for permitted operation", "format": "string"}, "optional": true}}]}}}], "type": "array", "$ref": "/axapi/v3/rba/role/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/rba`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "rba"
        self.a10_url="/axapi/v3/rba"
        self.DeviceProxy = ""
        self.action = ""
        self.group_list = []
        self.user_list = []
        self.role_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Snmp(A10BaseClass):
    
    """Class Description::
    Specify SNMP template.

    Class snmp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param username: {"description": "Specify username (User name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param interval: {"description": "Specify interval, default is 3 (Interval, unit: second, default is 3)", "format": "number", "default": 3, "optional": true, "maximum": 999, "minimum": 1, "type": "number"}
    :param priv_proto: {"description": "'aes': AES; 'des': DES; ", "format": "enum", "default": "des", "type": "string", "enum": ["aes", "des"], "optional": true}
    :param context_name: {"description": "Specify context name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param auth_key: {"description": "Specify authentication key (Specify key)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param oid: {"description": "Specify OID", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param security_level: {"description": "'no-auth': No authentication; 'auth-no-priv': Authentication, but no privacy; 'auth-priv': Authentication and privacy; ", "format": "enum", "default": "no-auth", "type": "string", "enum": ["no-auth", "auth-no-priv", "auth-priv"], "optional": true}
    :param community: {"description": "Specify community for version 2c (Community name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param port: {"description": "Specify port, default is 161 (Port Number, default is 161)", "format": "number", "default": 161, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param host: {"description": "Specify host (Host name or ip address)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param version: {"description": "'v1': Version 1; 'v2c': Version 2c; 'v3': Version 3; ", "format": "enum", "default": "v3", "type": "string", "enum": ["v1", "v2c", "v3"], "optional": true}
    :param interface: {"optional": true, "type": "number", "description": "Specify Interface ID", "format": "number"}
    :param priv_key: {"description": "Specify privacy key (Specify key)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param auth_proto: {"description": "'sha': SHA; 'md5': MD5; ", "format": "enum", "default": "md5", "type": "string", "enum": ["sha", "md5"], "optional": true}
    :param security_engine_id: {"description": "Specify security engine ID", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param snmp_name: {"description": "Specify name of snmp template", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param context_engine_id: {"description": "Specify context engine ID", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/template/snmp/{snmp_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "snmp_name"]

        self.b_key = "snmp"
        self.a10_url="/axapi/v3/gslb/template/snmp/{snmp_name}"
        self.DeviceProxy = ""
        self.username = ""
        self.interval = ""
        self.priv_proto = ""
        self.context_name = ""
        self.auth_key = ""
        self.oid = ""
        self.security_level = ""
        self.community = ""
        self.port = ""
        self.host = ""
        self.version = ""
        self.interface = ""
        self.priv_key = ""
        self.auth_proto = ""
        self.security_engine_id = ""
        self.snmp_name = ""
        self.context_engine_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ExtcommunityLStdCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param exact_match: {"default": 0, "type": "number", "description": "Do exact matching of ecommunities", "format": "flag"}
    :param l_std: {"description": "Community-list number (standard)", "format": "number", "not-list": ["l-ext", "name"], "maximum": 99, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "extcommunity-l-std-cfg"
        self.DeviceProxy = ""
        self.exact_match = ""
        self.l_std = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ExtcommunityLName(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param exact_match: {"default": 0, "type": "number", "description": "Do exact matching of ecommunities", "format": "flag"}
    :param name: {"description": "Community-list name", "format": "string", "minLength": 1, "not-list": ["l-std", "l-ext"], "maxLength": 128, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "extcommunity-l-name"
        self.DeviceProxy = ""
        self.exact_match = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ExtcommunityLExtCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param exact_match: {"default": 0, "type": "number", "description": "Do exact matching of ecommunities", "format": "flag"}
    :param l_ext: {"description": "Community-list number (expanded)", "format": "number", "not-list": ["l-std", "name"], "maximum": 199, "minimum": 100, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "extcommunity-l-ext-cfg"
        self.DeviceProxy = ""
        self.exact_match = ""
        self.l_ext = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Extcommunity(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "extcommunity"
        self.DeviceProxy = ""
        self.extcommunity_l_std_cfg = {}
        self.extcommunity_l_name = {}
        self.extcommunity_l_ext_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Origin(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param egp: {"default": 0, "not-list": ["igp", "incomplete"], "type": "number", "description": "remote EGP", "format": "flag"}
    :param incomplete: {"default": 0, "not-list": ["egp", "igp"], "type": "number", "description": "unknown heritage", "format": "flag"}
    :param igp: {"default": 0, "not-list": ["egp", "incomplete"], "type": "number", "description": "local IGP", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "origin"
        self.DeviceProxy = ""
        self.egp = ""
        self.incomplete = ""
        self.igp = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Group(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param group_id: {"description": "HA or VRRP-A group id", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}
    :param ha_state: {"enum": ["active", "standby"], "type": "string", "description": "'active': HA or VRRP-A in Active State; 'standby': HA or VRRP-A in Standby State; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "group"
        self.DeviceProxy = ""
        self.group_id = ""
        self.ha_state = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Peer(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param acl1: {"description": "IP access-list number", "format": "number", "not-list": ["acl2", "name"], "maximum": 199, "minimum": 1, "type": "number"}
    :param acl2: {"description": "IP access-list number (expanded range)", "format": "number", "not-list": ["acl1", "name"], "maximum": 2699, "minimum": 1300, "type": "number"}
    :param name: {"description": "IP access-list name", "format": "string", "minLength": 1, "not-list": ["acl1", "acl2"], "maxLength": 128, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "peer"
        self.DeviceProxy = ""
        self.acl1 = ""
        self.acl2 = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PrefixList1(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param name: {"minLength": 1, "maxLength": 128, "type": "string", "description": "IP prefix-list name", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "prefix-list-1"
        self.DeviceProxy = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NextHop(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param acl1: {"description": "IP access-list number", "format": "number", "not-list": ["acl2", "name"], "maximum": 199, "minimum": 1, "type": "number"}
    :param acl2: {"description": "IP access-list number (expanded range)", "format": "number", "not-list": ["acl1", "name"], "maximum": 2699, "minimum": 1300, "type": "number"}
    :param name: {"description": "IP access-list name", "format": "string", "minLength": 1, "not-list": ["acl1", "acl2"], "maxLength": 128, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "next-hop"
        self.DeviceProxy = ""
        self.acl1 = ""
        self.acl2 = ""
        self.name = ""
        self.prefix_list_1 = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PrefixList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param name: {"minLength": 1, "maxLength": 128, "type": "string", "description": "IP prefix-list name", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "prefix-list"
        self.DeviceProxy = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Address(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param acl1: {"description": "IP access-list number", "format": "number", "not-list": ["acl2", "name"], "maximum": 199, "minimum": 1, "type": "number"}
    :param acl2: {"description": "IP access-list number (expanded range)", "format": "number", "not-list": ["acl1", "name"], "maximum": 2699, "minimum": 1300, "type": "number"}
    :param name: {"description": "IP access-list name", "format": "string", "minLength": 1, "not-list": ["acl1", "acl2"], "maxLength": 128, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "address"
        self.DeviceProxy = ""
        self.acl1 = ""
        self.acl2 = ""
        self.prefix_list = {}
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ip(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip"
        self.DeviceProxy = ""
        self.peer = {}
        self.next_hop = {}
        self.address = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Metric(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param value: {"description": "Metric value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "metric"
        self.DeviceProxy = ""
        self.value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NextHop1(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param prefix_list_name: {"minLength": 1, "maxLength": 128, "type": "string", "description": "IPv6 prefix-list name", "format": "string"}
    :param v6_addr: {"not": "next-hop-acl-name", "type": "string", "description": "IPv6 address of next hop", "format": "ipv6-address"}
    :param next_hop_acl_name: {"description": "IPv6 access-list name", "format": "string", "minLength": 1, "maxLength": 128, "not": "v6-addr", "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "next-hop-1"
        self.DeviceProxy = ""
        self.prefix_list_name = ""
        self.v6_addr = ""
        self.next_hop_acl_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Peer1(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param acl1: {"description": "IPv6 access-list number", "format": "number", "not-list": ["acl2", "name"], "maximum": 199, "minimum": 1, "type": "number"}
    :param acl2: {"description": "IP access-list number (expanded range)", "format": "number", "not-list": ["acl1", "name"], "maximum": 2699, "minimum": 1300, "type": "number"}
    :param name: {"description": "IP access-list name", "format": "string", "minLength": 1, "not-list": ["acl1", "acl2"], "maxLength": 128, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "peer-1"
        self.DeviceProxy = ""
        self.acl1 = ""
        self.acl2 = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PrefixList2(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param name: {"minLength": 1, "maxLength": 128, "type": "string", "description": "IPv6 prefix-list name", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "prefix-list-2"
        self.DeviceProxy = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Address1(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param name: {"minLength": 1, "maxLength": 128, "type": "string", "description": "IPv6 access-list name", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "address-1"
        self.DeviceProxy = ""
        self.name = ""
        self.prefix_list_2 = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv6"
        self.DeviceProxy = ""
        self.next_hop_1 = {}
        self.peer_1 = {}
        self.address_1 = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LStdCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param exact_match: {"default": 0, "type": "number", "description": "Do exact matching of ecommunities", "format": "flag"}
    :param l_std: {"description": "Community-list number (standard)", "format": "number", "not-list": ["l-ext", "name"], "maximum": 99, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "l-std-cfg"
        self.DeviceProxy = ""
        self.exact_match = ""
        self.l_std = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NameCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param exact_match: {"default": 0, "type": "number", "description": "Do exact matching of ecommunities", "format": "flag"}
    :param name: {"description": "Community-list name", "format": "string", "minLength": 1, "not-list": ["l-std", "l-ext"], "maxLength": 128, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "name-cfg"
        self.DeviceProxy = ""
        self.exact_match = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LExtCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param exact_match: {"default": 0, "type": "number", "description": "Do exact matching of ecommunities", "format": "flag"}
    :param l_ext: {"description": "Community-list number (expanded)", "format": "number", "not-list": ["l-std", "name"], "maximum": 199, "minimum": 100, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "l-ext-cfg"
        self.DeviceProxy = ""
        self.exact_match = ""
        self.l_ext = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Community(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "community"
        self.DeviceProxy = ""
        self.l_std_cfg = {}
        self.name_cfg = {}
        self.l_ext_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LocalPreference(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param val: {"description": "Preference value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "local-preference"
        self.DeviceProxy = ""
        self.val = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class External(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param value: {"enum": ["type-1", "type-2"], "type": "string", "description": "'type-1': Match OSPF External Type 1 metrics; 'type-2': Match OSPF External Type 2 metrics; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "external"
        self.DeviceProxy = ""
        self.value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RouteType(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "route-type"
        self.DeviceProxy = ""
        self.external = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Tag(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param value: {"description": "Tag value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "tag"
        self.DeviceProxy = ""
        self.value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AsPath(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param name: {"minLength": 1, "maxLength": 128, "type": "string", "description": "AS path access-list name", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "as-path"
        self.DeviceProxy = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Interface(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ethernet: {"not-list": ["loopback", "trunk", "ve"], "type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}
    :param trunk: {"description": "Trunk Interface (Trunk interface number)", "format": "number", "not-list": ["ethernet", "loopback", "ve"], "maximum": 16, "minimum": 1, "type": "number"}
    :param ve: {"description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "number", "not-list": ["ethernet", "loopback", "trunk"], "maximum": 4094, "minimum": 2, "type": "number"}
    :param loopback: {"description": "Loopback interface (Port number)", "format": "number", "not-list": ["ethernet", "trunk", "ve"], "maximum": 10, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "interface"
        self.DeviceProxy = ""
        self.ethernet = ""
        self.trunk = ""
        self.ve = ""
        self.loopback = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Match(A10BaseClass):
    
    """Class Description::
    Match values from routing table.

    Class match supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/route-map/{tag}+{action}+{sequence}/match`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "match"
        self.a10_url="/axapi/v3/route-map/{tag}+{action}+{sequence}/match"
        self.DeviceProxy = ""
        self.extcommunity = {}
        self.origin = {}
        self.group = {}
        self.ip = {}
        self.metric = {}
        self.ipv6 = {}
        self.community = {}
        self.local_preference = {}
        self.route_type = {}
        self.tag = {}
        self.as_path = {}
        self.interface = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AuthKey(A10BaseClass):
    
    """Class Description::
    authentication key.

    Class auth-key supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param encrypted: {"not": "hex-encrypted", "optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param key_type: {"optional": true, "enum": ["ascii", "hex"], "type": "string", "description": "'ascii': key string in ASCII form; 'hex': key string in hex form; ", "format": "enum"}
    :param hex_encrypted: {"not": "encrypted", "optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param hex_key: {"format": "password", "minLength": 21, "optional": true, "maxLength": 40, "not": "asc-key", "type": "string"}
    :param alg_type: {"optional": true, "enum": ["M", "SHA", "SHA1"], "type": "string", "description": "'M': encryption using MD5; 'SHA': encryption using SHA; 'SHA1': encryption using SHA1; ", "format": "enum"}
    :param key: {"description": "authentication key", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param asc_key: {"format": "password", "minLength": 1, "optional": true, "maxLength": 20, "not": "hex-key", "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ntp/auth-key/{key}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "key"]

        self.b_key = "auth-key"
        self.a10_url="/axapi/v3/ntp/auth-key/{key}"
        self.DeviceProxy = ""
        self.encrypted = ""
        self.key_type = ""
        self.hex_encrypted = ""
        self.hex_key = ""
        self.alg_type = ""
        self.key = ""
        self.asc_key = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Interface(A10BaseClass):
    
    """Class Description::
    VRRP-A interface.

    Class interface supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param trunk_list: {"minItems": 1, "items": {"type": "trunk"}, "uniqueItems": true, "array": [{"required": ["trunk-val"], "properties": {"both": {"description": "both a router and server interface", "format": "flag", "default": 0, "optional": true, "not-list": ["router-interface", "server-interface"], "type": "number"}, "vlan": {"description": "VLAN ID", "format": "number", "optional": true, "maximum": 4094, "minimum": 1, "not": "no-heartbeat", "type": "number"}, "router-interface": {"description": "interface to upstream router", "format": "flag", "default": 0, "optional": true, "not-list": ["server-interface", "both"], "type": "number"}, "no-heartbeat": {"description": "do not send out heartbeat packet from this interface", "format": "flag", "default": 0, "optional": true, "not": "vlan", "type": "number"}, "server-interface": {"description": "interface to real server", "format": "flag", "default": 0, "optional": true, "not-list": ["router-interface", "both"], "type": "number"}, "trunk-val": {"description": "Ethernet Interface", "format": "number", "type": "number", "maximum": 16, "minimum": 1, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/vrrp-a/interface/trunk/{trunk-val}"}
    :param ethernet_list: {"minItems": 1, "items": {"type": "ethernet"}, "uniqueItems": true, "array": [{"required": ["ethernet-val"], "properties": {"both": {"description": "both a router and server interface", "format": "flag", "default": 0, "optional": true, "not-list": ["router-interface", "server-interface"], "type": "number"}, "vlan": {"description": "VLAN ID", "format": "number", "optional": true, "maximum": 4094, "minimum": 1, "not": "no-heartbeat", "type": "number"}, "ethernet-val": {"optional": false, "type": "number", "description": "Ethernet Interface", "format": "interface"}, "router-interface": {"description": "interface to upstream router", "format": "flag", "default": 0, "optional": true, "not-list": ["server-interface", "both"], "type": "number"}, "no-heartbeat": {"description": "do not send out heartbeat packet from this interface", "format": "flag", "default": 0, "optional": true, "not": "vlan", "type": "number"}, "server-interface": {"description": "interface to real server", "format": "flag", "default": 0, "optional": true, "not-list": ["router-interface", "both"], "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/vrrp-a/interface/ethernet/{ethernet-val}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vrrp-a/interface`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "interface"
        self.a10_url="/axapi/v3/vrrp-a/interface"
        self.DeviceProxy = ""
        self.trunk_list = []
        self.ethernet_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param num_tx_pkts: {"optional": true, "size": "8", "type": "number", "oid": "6", "format": "counter"}
    :param dropped_dis_tx_pkts: {"optional": true, "size": "8", "type": "number", "oid": "13", "format": "counter"}
    :param num_total_tx_bytes: {"optional": true, "size": "8", "type": "number", "oid": "7", "format": "counter"}
    :param num_multicast_pkts: {"optional": true, "size": "2", "type": "number", "oid": "5", "format": "counter"}
    :param num_unicast_pkts: {"optional": true, "size": "8", "type": "number", "oid": "3", "format": "counter"}
    :param num_broadcast_tx_pkts: {"optional": true, "size": "8", "type": "number", "oid": "9", "format": "counter"}
    :param num_broadcast_pkts: {"optional": true, "size": "8", "type": "number", "oid": "4", "format": "counter"}
    :param num_multicast_tx_pkts: {"optional": true, "size": "8", "type": "number", "oid": "10", "format": "counter"}
    :param num_unicast_tx_pkts: {"optional": true, "size": "8", "type": "number", "oid": "8", "format": "counter"}
    :param dropped_rx_pkts: {"optional": true, "size": "8", "type": "number", "oid": "12", "format": "counter"}
    :param num_total_bytes: {"optional": true, "size": "8", "type": "number", "oid": "2", "format": "counter"}
    :param num_pkts: {"optional": true, "size": "8", "type": "number", "oid": "1", "format": "counter"}
    :param dropped_dis_rx_pkts: {"optional": true, "size": "8", "type": "number", "oid": "11", "format": "counter"}
    :param dropped_tx_pkts: {"optional": true, "size": "8", "type": "number", "oid": "14", "format": "counter"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.num_tx_pkts = ""
        self.dropped_dis_tx_pkts = ""
        self.num_total_tx_bytes = ""
        self.num_multicast_pkts = ""
        self.num_unicast_pkts = ""
        self.num_broadcast_tx_pkts = ""
        self.num_broadcast_pkts = ""
        self.num_multicast_tx_pkts = ""
        self.num_unicast_tx_pkts = ""
        self.dropped_rx_pkts = ""
        self.num_total_bytes = ""
        self.num_pkts = ""
        self.dropped_dis_rx_pkts = ""
        self.dropped_tx_pkts = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Lif(A10BaseClass):
    
    """Class Description::
    Statistics for the object lif.

    Class lif supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ifnum: {"description": "Lif interface number", "format": "number", "optional": false, "oid": "1001", "maximum": 128, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/lif/{ifnum}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ifnum"]

        self.b_key = "lif"
        self.a10_url="/axapi/v3/interface/lif/{ifnum}/stats"
        self.DeviceProxy = ""
        self.ip = {}
        self.ifnum = ""
        self.isis = {}
        self.stats = {}
        self.bfd = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Pcp(A10BaseClass):
    
    """Class Description::
    Port Control Protocol Template.

    Class pcp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param source_ipv6: {"optional": true, "type": "string", "description": "Specify source IPv6 address for IPv6 ANNOUNCE message", "format": "ipv6-address"}
    :param allow_third_party_from_lan: {"default": 0, "optional": true, "type": "number", "description": "Allow third party request coming from LAN (default is disabled)", "format": "flag"}
    :param name: {"description": "PCP Template name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param map: {"default": 0, "optional": true, "type": "number", "description": "PCP MAP Opcode (default is enabled)", "format": "flag"}
    :param allow_third_party_from_wan: {"default": 0, "optional": true, "type": "number", "description": "Allow third party request coming from WAN (default is disabled)", "format": "flag"}
    :param maximum: {"description": "To set maximum lifetime of PCP mappings (default 1440 minutes)", "format": "number", "default": 1440, "optional": true, "maximum": 1440, "minimum": 2, "type": "number"}
    :param disable_map_filter: {"default": 0, "optional": true, "type": "number", "description": "To disable processing of FILTER options in MAP request", "format": "flag"}
    :param peer: {"default": 0, "optional": true, "type": "number", "description": "PCP PEER Opcode (default is enabled)", "format": "flag"}
    :param minimum: {"description": "To set minimum lifetime of PCP mappings (default 2 minutes)", "format": "number", "default": 2, "optional": true, "maximum": 1440, "minimum": 2, "type": "number"}
    :param check_client_nonce: {"default": 0, "optional": true, "type": "number", "description": "To validate NONCE value in PCP request (default: disabled)", "format": "flag"}
    :param announce: {"default": 0, "optional": true, "type": "number", "description": "PCP ANNOUNCE Opcode (default is enabled)", "format": "flag"}
    :param source_ip: {"optional": true, "type": "string", "description": "Specify source IP address for IPv4 ANNOUNCE message", "format": "ipv4-address"}
    :param pcp_server_port: {"description": "PCP server listening port (default 5351) (PCP UDP destination port)", "format": "number", "default": 5351, "optional": true, "maximum": 65535, "minimum": 1024, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/template/pcp/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "pcp"
        self.a10_url="/axapi/v3/cgnv6/template/pcp/{name}"
        self.DeviceProxy = ""
        self.source_ipv6 = ""
        self.allow_third_party_from_lan = ""
        self.name = ""
        self.A10WW_map = ""
        self.allow_third_party_from_wan = ""
        self.maximum = ""
        self.disable_map_filter = ""
        self.peer = ""
        self.minimum = ""
        self.check_client_nonce = ""
        self.announce = ""
        self.source_ip = ""
        self.pcp_server_port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SlbDev(A10BaseClass):
    
    """Class Description::
    Specify a SLB device for the GSLB site.

    Class slb-dev supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param client_ip: {"optional": true, "type": "string", "description": "Specify client IP address", "format": "ipv4-address"}
    :param device_name: {"description": "Specify SLB device name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param proto_aging_fast: {"default": 1, "optional": true, "type": "number", "description": "Fast GSLB Protocol aging", "format": "flag"}
    :param proto_compatible: {"default": 0, "optional": true, "type": "number", "description": "Run GSLB Protocol in compatible mode", "format": "flag"}
    :param auto_map: {"default": 1, "optional": true, "type": "number", "description": "Enable DNS Auto Mapping", "format": "flag"}
    :param proto_aging_time: {"description": "Specify GSLB Protocol aging time, default is 60", "format": "number", "default": 60, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param rdt_value: {"description": "Specify Round-delay-time", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param admin_preference: {"description": "Specify administrative preference (Specify admin-preference value,default is 100)", "format": "number", "default": 100, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}
    :param ip_address: {"optional": true, "type": "string", "description": "IP address", "format": "ipv4-address"}
    :param auto_detect: {"description": "'ip': Service IP only; 'port': Service Port only; 'ip-and-port': Both service IP and service port; 'disabled': disable auto-detect; ", "format": "enum", "default": "ip-and-port", "type": "string", "enum": ["ip", "port", "ip-and-port", "disabled"], "optional": true}
    :param health_check_action: {"description": "'health-check': Enable health Check; 'health-check-disable': Disable health check; ", "format": "enum", "default": "health-check", "type": "string", "enum": ["health-check", "health-check-disable"], "optional": true}
    :param max_client: {"description": "Specify maximum number of clients, default is 32768", "format": "number", "default": 32768, "optional": true, "maximum": 2147483647, "minimum": 1, "type": "number"}
    :param gateway_ip_addr: {"optional": true, "type": "string", "description": "IP address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/site/{site_name}/slb-dev/{device_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "device_name"]

        self.b_key = "slb-dev"
        self.a10_url="/axapi/v3/gslb/site/{site_name}/slb-dev/{device_name}"
        self.DeviceProxy = ""
        self.client_ip = ""
        self.vip_server = {}
        self.device_name = ""
        self.proto_aging_fast = ""
        self.proto_compatible = ""
        self.auto_map = ""
        self.proto_aging_time = ""
        self.rdt_value = ""
        self.admin_preference = ""
        self.ip_address = ""
        self.auto_detect = ""
        self.health_check_action = ""
        self.max_client = ""
        self.gateway_ip_addr = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


